class Image():
    '''Klasse für SVG-Vektorgrafiken'''

    def __init__(self, width=600, height=400):
        '''Erzeugt ein Bild der Grösse width x height'''
        self.width = width
        self.height = height
        self.line_width = 2
        self.line_color = 'rgb(0,0,0)'
        self.fill_color = 'none'
        self.code = ''

    def set_line_width(self, width):
        self.line_width = width

    def set_line_color(self, R, G, B):
        self.line_color = 'rgb({0},{1},{2}'.format(R, G, B)

    def write_svg_file(self, dateiname):
        '''Speichert das Bild unter dateiname'''
        txt  = '<?xml version="1.0" encoding="utf-8"?>\n'
        txt += '<svg xmlns="http://www.w3.org/2000/svg" '
        txt += 'width="{0}" '.format(self.width)
        txt += 'height="{0}">\n\n'.format(self.height)
        txt += self.code
        txt += '</svg>\n'
        
        fd = open(dateiname, mode='w')
        fd.write(txt)
        print('Datei "{0}" erstellt.'.format(dateiname))
        fd.close()

    def draw_line(self, P1, P2):
        '''Linie durch die Punkte P1=[x1,y1] und P2=[x2,y2]'''
        txt  = '<line x1="{0[0]}" y1="{0[1]}" '.format(P1)
        txt += 'x2="{0[0]}" y2="{0[1]}" '.format(P2)   
        txt += 'stroke-width="{0}" '.format(self.line_width)
        txt += 'stroke="{0}" '.format(self.line_color)
        txt += '/>\n\n'
        self.code += txt

    def draw_circle(self, M, r):
        '''Kreis mit Mittelpunkt M=[x,y] und Radius r'''
        txt  = '<circle '
        txt += 'cx="{0}" '.format(M[0])
        txt += 'cy="{0}" '.format(M[1])
        txt += 'r="{0}" '.format(r)   
        txt += 'stroke-width="{0}" '.format(self.line_width)
        txt += 'stroke="{0}" '.format(self.line_color)
        txt += 'fill="{0}" '.format(self.fill_color)
        txt += '/>\n\n'
        self.code += txt

        
